"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.ThemedTextInput = void 0;
const react_1 = __importDefault(require("react"));
const react_native_paper_1 = require("react-native-paper");
const useAlternateTheme_1 = require("./hooks/useAlternateTheme");
/**
 * ThemedTextInput component
 *
 * This component is a wrapper around the React Native Paper [TextInput](https://callstack.github.io/react-native-paper/text-input.html)
 * component. It accepts all the same props as the RNP component. The wrapper simply performs some minor theme / style overrides
 * in order to make the component look the way we want for Brightlayer UI projects.
 */
// eslint-disable-next-line @typescript-eslint/ban-types
const ThemedTextInputRender = (props, ref // eslint-disable-line @typescript-eslint/ban-types
) => {
    // Necessary to allow use of ref (to pass focus to next TextInput on submit)
    const inputRef = react_1.default.useRef(null);
    react_1.default.useImperativeHandle(ref, () => ({
        focus: () => {
            if (inputRef && inputRef.current)
                inputRef.current.focus();
        },
    }));
    const { theme: themeOverride, style, ...other } = props;
    const fullTheme = react_native_paper_1.useTheme(themeOverride);
    const backgroundColorLight = props.mode === 'outlined' ? fullTheme.colors.surface : fullTheme.colors.background;
    const backgroundColorDark = props.mode === 'outlined'
        ? fullTheme.colors.surface
        : fullTheme.colors.actionPalette?.background || fullTheme.colors.background;
    const backgroundColor = fullTheme.dark ? backgroundColorDark : backgroundColorLight;
    const theme = useAlternateTheme_1.useAlternateTheme(themeOverride, {
        colors: {
            background: backgroundColorLight,
            // disabled: fullTheme.colors.disabled, // disabled-label disabled-outline
            placeholder: fullTheme.colors.textPalette?.secondary || fullTheme.colors.text,
        },
    }, {
        colors: {
            primary: fullTheme.colors.primaryPalette?.main || fullTheme.colors.primary,
            background: backgroundColorDark,
        },
    });
    return (react_1.default.createElement(react_native_paper_1.TextInput, Object.assign({}, other, { 
        // @ts-ignore issue with refs on RNP input
        ref: inputRef, style: props.mode !== 'outlined' ? [{ backgroundColor }, style] : style, outlineColor: props.outlineColor || fullTheme.colors.divider, theme: theme })));
};
// Necessary to allow use of ref (to pass focus to next TextInput on submit)
exports.ThemedTextInput = react_1.default.forwardRef(ThemedTextInputRender);
react_native_paper_1.TextInput.displayName = 'ThemedTextInput';
